@@ -16,13 +16,10 @@ logger = logging.getLogger(__name__)
 
 
 class AutoKeyModule(AbstractSyncInputModule):
-    """ Auto Key module
-    """
+    """Auto Key module"""
 
     def __init__(self, key_gen_func):
-        """Initializes the module
-
-        """
+        """Initializes the module"""
         if key_gen_func is None:
             raise ModuleError(
                 "A function for the generation of the keys should be provided (key_gen_func is None)."
@@ -32,7 +29,7 @@ class AutoKeyModule(AbstractSyncInputModule):
         AbstractSyncInputModule.__init__(self, modclass="mod_auto_key", disabled=True)
 
     def _render_module(self, request):
-        """ Returns the module
+        """Returns the module
 
         Args:
             request:
@@ -58,12 +55,14 @@ class AutoKeyModule(AbstractSyncInputModule):
                 # get module id
                 module_id = request.GET["module_id"]
                 # get module element form module id
-                module = data_structure_element_api.get_by_id(module_id)
+                module = data_structure_element_api.get_by_id(module_id, request)
                 # get key id form module
                 key_id = module.options["params"]["key"]
 
                 # get XML document root element from module element
-                root_element = data_structure_element_api.get_root_element(module)
+                root_element = data_structure_element_api.get_root_element(
+                    module, request
+                )
                 try:
                     # get auto key manager from db
                     auto_key = auto_key_api.get_by_root(root_element)
@@ -96,7 +95,7 @@ class AutoKeyModule(AbstractSyncInputModule):
                     for key_module_id in module_ids:
                         try:
                             key_module = data_structure_element_api.get_by_id(
-                                key_module_id
+                                key_module_id, request
                             )
                             if key_module.options["data"] is not None:
                                 values.append(key_module.options["data"])
